Utils Module
============

The utils module will provide utility functions for data handling and reporting.

.. automodule:: actuneo.utils
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* Excel import/export
* CSV data handling
* Data validation
* Report generation
* Visualization helpers
* Workflow automation tools

